@@ -2,17 +2,7 @@
 #
 # Copyright 2014 Hewlett-Packard Development Company, L.P.
 #
-# Licensed under the Apache License, Version 2.0 (the "License"); you may
-# not use this file except in compliance with the License. You may obtain
-# a copy of the License at
-#
-#      http://www.apache.org/licenses/LICENSE-2.0
-#
-# Unless required by applicable law or agreed to in writing, software
-# distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
-# WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
-# License for the specific language governing permissions and limitations
-# under the License.
+# SPDX-License-Identifier: Apache-2.0
 
 import collections
 import fnmatch
@@ -190,6 +180,9 @@ class BanditManager(object):
         # if there are command line provided exclusions add them to the list
         if excluded_paths:
             for path in excluded_paths.split(','):
+                if os.path.isdir(path):
+                    path = os.path.join(path, '*')
+
                 excluded_path_globs.append(path)
 
         # build list of files we will analyze
@@ -227,9 +220,7 @@ class BanditManager(object):
 
         :return: -
         '''
-        # display progress, if number of files warrants it
-        if len(self.files_list) > self.progress:
-            sys.stderr.write("%s [" % len(self.files_list))
+        self._show_progress("%s [" % len(self.files_list))
 
         # if we have problems with a file, we'll remove it from the files_list
         # and add it to the skipped list instead
@@ -241,8 +232,7 @@ class BanditManager(object):
             if len(self.files_list) > self.progress:
                 # is it time to update the progress indicator?
                 if count % self.progress == 0:
-                    sys.stderr.write("%s.. " % count)
-                    sys.stderr.flush()
+                    self._show_progress("%s.. " % count, flush=True)
             try:
                 if fname == '-':
                     sys.stdin = os.fdopen(sys.stdin.fileno(), 'rb', 0)
@@ -254,9 +244,7 @@ class BanditManager(object):
                 self.skipped.append((fname, e.strerror))
                 new_files_list.remove(fname)
 
-        if len(self.files_list) > self.progress:
-            sys.stderr.write("]\n")
-            sys.stderr.flush()
+        self._show_progress("]\n", flush=True)
 
         # reflect any files which may have been skipped
         self.files_list = new_files_list
@@ -264,6 +252,22 @@ class BanditManager(object):
         # do final aggregation of metrics
         self.metrics.aggregate()
 
+    def _show_progress(self, message, flush=False):
+        '''Show progress on stderr
+
+        Write progress message to stderr, if number of files warrants it and
+        log level is high enough.
+
+        :param message: The message to write to stderr
+        :param flush: Whether to flush stderr after writing the message
+        :return:
+        '''
+        if len(self.files_list) > self.progress and \
+                LOG.getEffectiveLevel() <= logging.INFO:
+            sys.stderr.write(message)
+            if flush:
+                sys.stderr.flush()
+
     def _parse_file(self, fname, fdata, new_files_list):
         try:
             # parse the current file
@@ -284,14 +288,14 @@ class BanditManager(object):
                         lineno for toktype, tokval, (lineno, _), _, _ in tokens
                         if toktype == tokenize.COMMENT and
                         '#nosec' in tokval or '# nosec' in tokval)
-                except tokenize.TokenError as e:
+                except tokenize.TokenError:
                     nosec_lines = set()
             score = self._execute_ast_visitor(fname, data, nosec_lines)
             self.scores.append(score)
             self.metrics.count_issues([score, ])
-        except KeyboardInterrupt as e:
+        except KeyboardInterrupt:
             sys.exit(2)
-        except SyntaxError as e:
+        except SyntaxError:
             self.skipped.append((fname,
                                  "syntax error while parsing AST from file"))
             new_files_list.remove(fname)
@@ -363,7 +367,8 @@ def _is_file_included(path, included_globs, excluded_path_strings,
     # if this is matches a glob of files we look at, and it isn't in an
     # excluded path
     if _matches_glob_list(path, included_globs) or not enforce_glob:
-        if not _matches_glob_list(path, excluded_path_strings):
+        if (not _matches_glob_list(path, excluded_path_strings) and
+                not any(x in path for x in excluded_path_strings)):
             return_value = True
 
     return return_value
