@@ -2,29 +2,22 @@
 #
 # Copyright 2014 Hewlett-Packard Development Company, L.P.
 #
-# Licensed under the Apache License, Version 2.0 (the "License"); you may
-# not use this file except in compliance with the License. You may obtain
-# a copy of the License at
-#
-#      http://www.apache.org/licenses/LICENSE-2.0
-#
-# Unless required by applicable law or agreed to in writing, software
-# distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
-# WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
-# License for the specific language governing permissions and limitations
-# under the License.
+# SPDX-License-Identifier: Apache-2.0
 
 
-from collections import OrderedDict
+import collections
 import logging
 
 
-logger = logging.getLogger(__name__)
+LOG = logging.getLogger(__name__)
 
 
-class BanditMetaAst():
+class BanditMetaAst(object):
 
-    nodes = OrderedDict()
+    nodes = collections.OrderedDict()
+
+    def __init__(self):
+        pass
 
     def add_node(self, node, parent_id, depth):
         '''Add a node to the AST node collection
@@ -35,7 +28,7 @@ class BanditMetaAst():
         :return: -
         '''
         node_id = hex(id(node))
-        logger.debug('adding node : %s [%s]', node_id, depth)
+        LOG.debug('adding node : %s [%s]', node_id, depth)
         self.nodes[node_id] = {
             'raw': node, 'parent_id': parent_id, 'depth': depth
         }
